<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>Modul SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>O modulu SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Modul Qmmp pro konverzi vzorkovací frekvence</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SRConverterSettingsDialog</name>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation type="unfinished">Nastavení modulu SRC</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation type="unfinished">Vzorkovací frekvence (Hz):</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="40"/>
        <source>Interpolation Engine:</source>
        <translation type="unfinished">Způsob interpolace:</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="48"/>
        <source>Best Sinc Interpolation</source>
        <translation type="unfinished">Nejlepší interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="53"/>
        <source>Medium Sinc Interpolation</source>
        <translation type="unfinished">Střední interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="58"/>
        <source>Fastest Sinc Interpolation</source>
        <translation type="unfinished">Nejrychlejší interpolace pomocí sinc</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="63"/>
        <source>ZOH Interpolation</source>
        <translation type="unfinished">Interpolace ZOH</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="68"/>
        <source>Linear Interpolation</source>
        <translation type="unfinished">Lineární interpolace</translation>
    </message>
</context>
</TS>
